# ToDo

You are a Python developer

- create a new Python project using uv
- use uv always
- name privacyforms.pdf
- Author Andreas Jung info@zopyx.com


We write some Python wrappers for "pdfcpu", https://pdfcpu.io/
for extracting PDF form information and for filling data into a PDF form.

- check for the existence of "pdfcpu"
- provide commandline tools via "click"

First, write a functinality to extract the/all forms from a PDF.
Write it as an API and a CLI for running/testing it locally.
Encapsulate the functionality into a class PDFFormExtractor.

There is a file FilledForm.pdf containing a form.

Full tests, full typing information, full testing coverage

Use ruff and ty for formatting, performing checks and ty for type checks.


